@@ -13,19 +13,18 @@
    Copyright 2022, HSPyLib team
 """
 
-import logging as log
-import os
-import re
 from collections import defaultdict
 from configparser import ConfigParser
-from typing import Any, Callable, Iterator, List, Optional, Type, Dict, TextIO
-
-import toml
-import yaml
-
 from hspylib.core.enums.charset import Charset
 from hspylib.core.tools.commons import run_dir, touch_file
 from hspylib.core.tools.dict_tools import flatten_dict
+from typing import Any, Callable, Dict, Iterator, List, Optional, TextIO, Type
+
+import logging as log
+import os
+import re
+import toml
+import yaml
 
 CONVERSION_FN = Type | Callable[[Any], Any]
 
