@@ -64,7 +64,9 @@ def lowercase(text: str) -> str:
 def camelcase(text: str, separator: str = " |-|_", upper: bool = False) -> str:
     """Return a copy of the string converted to camel case.
     Ref:https://en.wikipedia.org/wiki/Letter_case :: Camel case"""
-    s = re.sub(rf"({separator})+", " ", text).title().replace(" ", "")
+    s = re.sub(rf"({separator})+", " ", text)
+    s = s.title()
+    s = re.sub(rf"({separator})+", "", s)
     fnc = getattr(s[0], "lower" if not upper else "upper")
     return "".join([fnc(), s[1:]])
 
